# Lunarcord - Discord Bot Library
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

A swift, fast, and beginner-friendly library for easily writing multi-purpose discord bots.
Inspired by discord, pycord, nextcord, and other discord forks.
This package is NOT a discord fork!

Written by **RevoLNo** 2024.